@@ -3,6 +3,7 @@ from parse_it.envvars.envvars import *
 from parse_it.file.yaml import *
 from parse_it.file.ini import *
 from parse_it.file.json import *
+from parse_it.file.env import *
 from parse_it.file.hcl import *
 from parse_it.file.toml import *
 from parse_it.file.xml import *
@@ -17,15 +18,15 @@ class ParseIt:
     def __init__(self, config_type_priority: Optional[list] = None, global_default_value: Any = None,
                  type_estimate: bool = True, recurse: bool = False, force_envvars_uppercase: bool = True,
                  config_location: Optional[str] = None, envvar_prefix: Optional[str] = None,
-                 custom_suffix_mapping: Optional[dict] = None):
+                 custom_suffix_mapping: Optional[dict] = None, envvar_divider: Optional[str] = None):
         """configures the object which is used to query all types of configuration inputs available and prioritize them
                 based on your needs
 
                     Arguments:
                         config_type_priority -- a list of file types extensions your willing to accept, list order
                             dictates priority of said file types, default list order is as follow:
-                            [ "cli_args", "envvars", "json", "yaml", "yml", "toml", "tml", "hcl", "tf", "conf", "cfg",
-                            "ini", "xml" ]
+                            [ "cli_args", "envvars", "env", "json", "yaml", "yml", "toml", "tml", "hcl", "tf", "conf",
+                            "cfg", "ini", "xml" ]
                             in the case of multiple files of same type they are all read and the first one that has the
                             needed key is the one used.
                             if no value is returned then the default_value declared at the read_configuration_variable
@@ -43,10 +44,15 @@ class ParseIt:
                             or if a standard file will look only in said file
                         envvar_prefix -- will add the given prefix for all envvars if set
                         custom_suffix_mapping -- a custom dict which will can map custom file suffixes to a file type
+                        envvar_divider -- the divider to split an envvar to nested dicts, if set to None (default) said
+                            nesting is disabled
         """
 
         # first we describe the standard file type suffix mapping and what file types are are standard file extensions
         self.suffix_file_type_mapping = {
+            "env": [
+                "env"
+            ],
             "json": [
                 "json"
             ],
@@ -72,6 +78,7 @@ class ParseIt:
             ]
         }
         self.valid_file_type_extension = [
+            "env",
             "json",
             "yaml",
             "yml",
@@ -85,7 +92,13 @@ class ParseIt:
             "xml"
         ]
 
-        # now we add any custom file suffixes the user wanted to the list of possible file extensions and valid
+        if envvar_divider is None:
+            self.nest_envvars = False
+        else:
+            self.nest_envvars = True
+            self.envvar_divider = envvar_divider
+
+            # now we add any custom file suffixes the user wanted to the list of possible file extensions and valid
         # suffixes
         if custom_suffix_mapping is not None:
             for file_type, custom_file_suffix in custom_suffix_mapping.items():
@@ -110,6 +123,7 @@ class ParseIt:
             self.config_type_priority = [
                 "cli_args",
                 "env_vars",
+                "env",
                 "json",
                 "yaml",
                 "yml",
@@ -188,7 +202,11 @@ class ParseIt:
                 config_value = read_envvar(self.envvar_prefix + config_name,
                                            force_uppercase=self.force_envvars_uppercase)
                 if config_key_found is True:
+                    # next the envvar if so desired to assist in matching to other file formats
+                    if self.nest_envvars is True:
+                        config_value = split_envvar(config_name, config_value, divider=self.envvar_divider)
                     break
+
             # will loop over all files of each type until all files of all types are searched, first time the key is
             # found will break outside of both loops
             elif config_type in self.valid_file_type_extension:
@@ -284,7 +302,11 @@ class ParseIt:
             if config_type == "cli_args":
                 config_value_dict.update(read_all_cli_args_to_dict())
             elif config_type == "envvars" or config_type == "env_vars":
-                config_value_dict.update(read_all_envvars_to_dict(force_uppercase=self.force_envvars_uppercase))
+                if self.nest_envvars is True:
+                    config_value_dict.update(split_envvar_combained_dict(divider=self.envvar_divider,
+                                                                         force_uppercase=self.force_envvars_uppercase))
+                else:
+                    config_value_dict.update(read_all_envvars_to_dict(force_uppercase=self.force_envvars_uppercase))
             # will loop over all files of each type until all files of all types are searched, first time the key is
             # found will break outside of both loops
             elif config_type in self.valid_file_type_extension:
@@ -370,6 +392,8 @@ class ParseIt:
             file_dict = parse_hcl_file(config_file_location)
         elif config_file_type in self.suffix_file_type_mapping["xml"]:
             file_dict = parse_xml_file(config_file_location)
+        elif config_file_type in self.suffix_file_type_mapping["env"]:
+            file_dict = parse_env_file(config_file_location)
         else:
             raise ValueError
         return file_dict
